TRContentCallback class abstract

TapResearch content callback for Survey Wall and Quick Question visibility events.

Constructors

TRContentCallback()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTapResearchContentDismissed(String placementTag) → void
Invoked whenever the Survey Wall activity is dismissed or a Quick Question dialog is dismissed.
onTapResearchContentShown(String placementTag) → void
Invoked whenever the Survey Wall activity is shown or a Quick Question appears on screen.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited