TRQQDataCallback class abstract

Indicates when a Quick Question has been answered and the dialog dismissed.

Constructors

TRQQDataCallback()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onQuickQuestionDataReceived(QQPayload data) → void
Invoked whenever a Quick Question has been completed and the dialog dismissed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited