onQuickQuestionDataReceived abstract method
Invoked whenever a Quick Question has been completed and the dialog dismissed.
data - Contains all data pertaining to the answered Quick Question.
Implementation
void onQuickQuestionDataReceived(QQPayload data);