QuickQuestionsDataPayloadQuestion class

Constructors

QuickQuestionsDataPayloadQuestion({required String questionIdentifier, required String questionText, required String questionType, int? ratingScaleSize, UserAnswer? userAnswer})
QuickQuestionsDataPayloadQuestion.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
questionIdentifier String
final
questionText String
final
questionType String
final
ratingScaleSize int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAnswer UserAnswer?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited