TRBonusBarProgress class

Constructors

TRBonusBarProgress({bool? isActive, int? currentCompletes, String? bonusWindowEndAt, List<TRBonusTier>? bonusTiers, TRError? error})
TRBonusBarProgress.fromJson(Map<String, dynamic> json)
factory

Properties

bonusTiers List<TRBonusTier>?
final
bonusWindowEndAt String?
final
currentCompletes int?
final
error TRError?
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited