TRBonusTier class

Constructors

TRBonusTier({int? tierNumber, int? completesNeeded, double? rewardAmount, String? status})
TRBonusTier.fromJson(Map<String, dynamic> json)
factory

Properties

completesNeeded int?
final
hashCode int
The hash code for this object.
no setterinherited
rewardAmount double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
tierNumber int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited