TRReward class
Constructors
- TRReward({String? transactionIdentifier, String? placementIdentifier, String? currencyName, double? rewardAmount, PayoutTypes? payoutEventType, String? placementTag})
-
TRReward.fromJson(Map<
String, dynamic> json) -
factory
Properties
- currencyName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payoutEventType → PayoutTypes?
-
final
- placementIdentifier → String?
-
final
- placementTag → String?
-
final
- rewardAmount → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionIdentifier → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited