TRSurvey class

Constructors

TRSurvey({String? surveyId, int? lengthInMinutes, double? rewardAmount, String? currencyName, bool? isSale, String? saleEndDate, double? saleMultiplier, double? preSaleRewardAmount, bool? isHotTile, String? category})
TRSurvey.fromJson(Map<String, dynamic> json)
factory

Properties

category String?
final
currencyName String?
final
hashCode int
The hash code for this object.
no setterinherited
isHotTile bool?
final
isSale bool?
final
lengthInMinutes int?
final
preSaleRewardAmount double?
final
rewardAmount double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleEndDate String?
final
saleMultiplier double?
final
surveyId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited