MethodChannelTapresearchFlutterPlugin class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canShowContentForPlacement(String tag, TRErrorCallback errorCallback) Future<bool>
override
getPlacementDetails(String placementTag, {TRErrorCallback? errorListener}) Future<TRPlacementDetails?>
override
getSurveysForPlacement(String placementTag, TRErrorCallback errorCallback) Future<List<TRSurvey>?>
override
grantBoost(String boostTag, {TRGrantBoostResponseListener? listener}) Future<void>
override
hasSurveysForPlacement(String placementTag, TRErrorCallback errorCallback) Future<bool>
override
initialize({required String apiToken, required String userIdentifier, TRRewardCallback? rewardCallback, required TRErrorCallback errorCallback, required TRSdkReadyCallback sdkReadyCallback, TRQQDataCallback? qqDataCallback, Map<String, dynamic>? userAttributes, bool? clearPreviousAttributes}) Future<void>
override
isReady() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendUserAttributes({required Map<String, dynamic> userAttributes, bool? clearPreviousAttributes, required TRErrorCallback errorCallback}) Future<void>
override
setSurveysRefreshedListener(TRSurveysRefreshedListener? listener) Future<void>
override
setUserIdentifier(String userIdentifier) Future<void>
override
showContentForPlacement({required String tag, TRContentCallback? contentCallback, Map<String, dynamic>? customParameters, required TRErrorCallback errorCallback}) Future<void>
override
showSurveyForPlacement({required String placementTag, required String surveyId, Map<String, dynamic>? customParameters, TRContentCallback? contentCallback, required TRErrorCallback errorCallback}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited