TRRewardCallback class abstract
Indicates a reward event has occurred, e.g. after a user successfully completes a survey and closes the Survey Wall.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTapResearchDidReceiveRewards(
List< TRReward> rewards) → void - Invoked whenever a reward is received. Can be triggered by survey completions, profile questionnaires, or previously un-redeemed rewards.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited