TRSdkReadyCallback class abstract
Indicates when the TapResearch SDK is ready for use and ready to display content such as the Survey Wall, Interstitials, and Quick Questions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTapResearchSdkReady(
) → void - Invoked shortly after TapResearch.initialize has been called, indicating the SDK is ready for use.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited