QQPayload class
Constructors
-
QQPayload({required String surveyIdentifier, required String appName, required String apiToken, required String sdkVersion, required String platform, required String placementTag, required String userIdentifier, required String userLocale, required String seenAt, Complete? complete, required List<
Question> questions, List<Map< ? targetAudience})String, String> > -
QQPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiToken → String
-
final
- appName → String
-
final
- complete → Complete?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- placementTag → String
-
final
- platform → String
-
final
-
questions
→ List<
Question> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion → String
-
final
- seenAt → String
-
final
- surveyIdentifier → String
-
final
-
targetAudience
→ List<
Map< ?String, String> > -
final
- userIdentifier → String
-
final
- userLocale → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited