TapresearchFlutterPluginPlatform class
abstract
- Inheritance
-
- Object
- PlatformInterface
- TapresearchFlutterPluginPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canShowContentForPlacement(String tag, TRErrorCallback errorCallback)
→ Future<bool>
-
-
getPlacementDetails(String placementTag, {TRErrorCallback? errorListener})
→ Future<TRPlacementDetails?>
-
-
getSurveysForPlacement(String placementTag, TRErrorCallback errorCallback)
→ Future<List<TRSurvey>?>
-
-
grantBoost(String boostTag, {TRGrantBoostResponseListener? listener})
→ Future<void>
-
-
hasSurveysForPlacement(String placementTag, TRErrorCallback errorCallback)
→ Future<bool>
-
-
initialize({required String apiToken, required String userIdentifier, TRRewardCallback? rewardCallback, required TRErrorCallback errorCallback, required TRSdkReadyCallback sdkReadyCallback, TRQQDataCallback? qqDataCallback, Map<String, dynamic>? userAttributes, bool? clearPreviousAttributes})
→ Future<void>
-
-
isReady()
→ Future<bool>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sendUserAttributes({required Map<String, dynamic> userAttributes, bool? clearPreviousAttributes, required TRErrorCallback errorCallback})
→ Future<void>
-
-
setSurveysRefreshedListener(TRSurveysRefreshedListener? listener)
→ Future<void>
-
-
setUserIdentifier(String userIdentifier)
→ Future<void>
-
-
showContentForPlacement({required String tag, TRContentCallback? contentCallback, Map<String, dynamic>? customParameters, required TRErrorCallback errorCallback})
→ Future<void>
-
-
showSurveyForPlacement({required String placementTag, required String surveyId, Map<String, dynamic>? customParameters, TRContentCallback? contentCallback, required TRErrorCallback errorCallback})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited